@@ -13,8 +13,9 @@ from datahub.configuration.source_common import (
 )
 from datahub.ingestion.source.aws.aws_common import AwsConnectionConfig
 from datahub.ingestion.source.aws.s3_util import is_s3_uri
-from datahub.ingestion.source.state.stateful_ingestion_base import (
+from datahub.ingestion.source.state.stale_entity_removal_handler import (
     StatefulIngestionConfigBase,
+    StatefulStaleMetadataRemovalConfig,
 )
 
 # hide annoying debug errors from py4j
@@ -39,9 +40,7 @@ class S3(ConfigModel):
 
 
 class DeltaLakeSourceConfig(
-    PlatformInstanceConfigMixin,
-    EnvConfigMixin,
-    StatefulIngestionConfigBase,
+    PlatformInstanceConfigMixin, EnvConfigMixin, StatefulIngestionConfigBase
 ):
     base_path: str = Field(
         description="Path to table (s3 or local file system). If path is not a delta table path "
@@ -78,7 +77,12 @@ class DeltaLakeSourceConfig(
         "When set to `False`, number_of_files in delta table can not be reported.",
     )
 
-    s3: Optional[S3] = Field()
+    s3: Optional[S3] = Field(None)
+
+    stateful_ingestion: Optional[StatefulStaleMetadataRemovalConfig] = Field(
+        default=None,
+        description="Stateful Ingestion Config with stale metadata removal",
+    )
 
     @cached_property
     def is_s3(self):
