@@ -1,4 +1,5 @@
 import logging
+import re
 import time
 from collections import defaultdict
 from concurrent.futures import ThreadPoolExecutor, as_completed
@@ -42,6 +43,7 @@ from datahub.ingestion.api.decorators import (
 )
 from datahub.ingestion.api.workunit import MetadataWorkUnit
 from datahub.ingestion.graph.client import DataHubGraph
+from datahub.ingestion.source.common.subtypes import SourceCapabilityModifier
 from datahub.ingestion.source.sql.sql_common import register_custom_type
 from datahub.ingestion.source.sql.sql_config import SQLCommonConfig
 from datahub.ingestion.source.sql.sql_report import SQLSourceReport
@@ -50,7 +52,6 @@ from datahub.ingestion.source.sql.two_tier_sql_source import (
     TwoTierSQLAlchemySource,
 )
 from datahub.ingestion.source.usage.usage_common import BaseUsageConfig
-from datahub.ingestion.source_report.ingestion_stage import IngestionStageReport
 from datahub.ingestion.source_report.time_window import BaseTimeWindowReport
 from datahub.metadata.com.linkedin.pegasus2avro.schema import (
     BytesTypeClass,
@@ -67,6 +68,12 @@ from datahub.utilities.stats_collections import TopKDict
 
 logger: logging.Logger = logging.getLogger(__name__)
 
+# Precompiled regex pattern for case-insensitive "(not casespecific)" removal
+NOT_CASESPECIFIC_PATTERN = re.compile(r"\(not casespecific\)", re.IGNORECASE)
+
+# Teradata uses a two-tier database.table naming approach without default database prefixing
+DEFAULT_NO_DATABASE_TERADATA = None
+
 # Common excluded databases used in multiple places
 EXCLUDED_DATABASES = [
     "All",
@@ -433,7 +440,7 @@ def optimized_get_view_definition(
 
 
 @dataclass
-class TeradataReport(SQLSourceReport, IngestionStageReport, BaseTimeWindowReport):
+class TeradataReport(SQLSourceReport, BaseTimeWindowReport):
     # View processing metrics (actively used)
     num_views_processed: int = 0
     num_view_processing_failures: int = 0
@@ -453,6 +460,13 @@ class TeradataReport(SQLSourceReport, IngestionStageReport, BaseTimeWindowReport
     # Global metadata extraction timing (single query for all databases)
     metadata_extraction_total_sec: float = 0.0
 
+    # Lineage extraction query time range (actively used)
+    lineage_start_time: Optional[datetime] = None
+    lineage_end_time: Optional[datetime] = None
+
+    # Audit query processing statistics
+    num_audit_query_entries_processed: int = 0
+
 
 class BaseTeradataConfig(TwoTierSQLAlchemyConfig):
     scheme: str = Field(default="teradatasql", description="database scheme")
@@ -467,23 +481,23 @@ class TeradataConfig(BaseTeradataConfig, BaseTimeWindowConfig):
         ),
     )
 
-    database_pattern = Field(
+    database_pattern: AllowDenyPattern = Field(
         default=AllowDenyPattern(deny=EXCLUDED_DATABASES),
         description="Regex patterns for databases to filter in ingestion.",
     )
-    include_table_lineage = Field(
+    include_table_lineage: bool = Field(
         default=False,
         description="Whether to include table lineage in the ingestion. "
         "This requires to have the table lineage feature enabled.",
     )
 
-    include_view_lineage = Field(
+    include_view_lineage: bool = Field(
         default=True,
         description="Whether to include view lineage in the ingestion. "
         "This requires to have the view lineage feature enabled.",
     )
 
-    include_queries = Field(
+    include_queries: bool = Field(
         default=True,
         description="Whether to generate query entities for SQL queries. "
         "Query entities provide metadata about individual SQL queries including "
@@ -539,7 +553,13 @@ class TeradataConfig(BaseTeradataConfig, BaseTimeWindowConfig):
 @config_class(TeradataConfig)
 @support_status(SupportStatus.TESTING)
 @capability(SourceCapability.DOMAINS, "Enabled by default")
-@capability(SourceCapability.CONTAINERS, "Enabled by default")
+@capability(
+    SourceCapability.CONTAINERS,
+    "Enabled by default",
+    subtype_modifier=[
+        SourceCapabilityModifier.DATABASE,
+    ],
+)
 @capability(SourceCapability.PLATFORM_INSTANCE, "Enabled by default")
 @capability(
     SourceCapability.DELETION_DETECTION,
@@ -720,7 +740,8 @@ ORDER by DataBaseName, TableName;
             env=self.config.env,
             schema_resolver=self.schema_resolver,
             graph=self.ctx.graph,
-            generate_lineage=self.include_lineage,
+            generate_lineage=self.config.include_view_lineage
+            or self.config.include_table_lineage,
             generate_queries=self.config.include_queries,
             generate_usage_statistics=self.config.include_usage_statistics,
             generate_query_usage_statistics=self.config.include_usage_statistics,
@@ -1321,6 +1342,9 @@ ORDER by DataBaseName, TableName;
         current_query_metadata = None
 
         for entry in entries:
+            # Count each audit query entry processed
+            self.report.num_audit_query_entries_processed += 1
+
             query_id = getattr(entry, "query_id", None)
             query_text = str(getattr(entry, "query_text", ""))
 
@@ -1361,15 +1385,18 @@ ORDER by DataBaseName, TableName;
         default_database = getattr(metadata_entry, "default_database", None)
 
         # Apply Teradata-specific query transformations
-        cleaned_query = full_query_text.replace("(NOT CASESPECIFIC)", "")
+        cleaned_query = NOT_CASESPECIFIC_PATTERN.sub("", full_query_text)
 
+        # For Teradata's two-tier architecture (database.table), we should not set default_db
+        # to avoid incorrect URN generation like "dbc.database.table" instead of "database.table"
+        # The SQL parser will treat database.table references correctly without default_db
         return ObservedQuery(
             query=cleaned_query,
             session_id=session_id,
             timestamp=timestamp,
             user=CorpUserUrn(user) if user else None,
-            default_db=default_database,
-            default_schema=default_database,  # Teradata uses database as schema
+            default_db=DEFAULT_NO_DATABASE_TERADATA,  # Teradata uses two-tier database.table naming without default database prefixing
+            default_schema=default_database,
         )
 
     def _convert_entry_to_observed_query(self, entry: Any) -> ObservedQuery:
@@ -1387,15 +1414,18 @@ ORDER by DataBaseName, TableName;
         default_database = getattr(entry, "default_database", None)
 
         # Apply Teradata-specific query transformations
-        cleaned_query = query_text.replace("(NOT CASESPECIFIC)", "")
+        cleaned_query = NOT_CASESPECIFIC_PATTERN.sub("", query_text)
 
+        # For Teradata's two-tier architecture (database.table), we should not set default_db
+        # to avoid incorrect URN generation like "dbc.database.table" instead of "database.table"
+        # However, we should set default_schema for unqualified table references
         return ObservedQuery(
             query=cleaned_query,
             session_id=session_id,
             timestamp=timestamp,
             user=CorpUserUrn(user) if user else None,
-            default_db=default_database,
-            default_schema=default_database,  # Teradata uses database as schema
+            default_db=DEFAULT_NO_DATABASE_TERADATA,  # Teradata uses two-tier database.table naming without default database prefixing
+            default_schema=default_database,  # Set default_schema for unqualified table references
         )
 
     def _fetch_lineage_entries_chunked(self) -> Iterable[Any]:
@@ -1415,7 +1445,7 @@ ORDER by DataBaseName, TableName;
 
                 for query_index, query in enumerate(queries, 1):
                     logger.info(
-                        f"Executing lineage query {query_index}/{len(queries)} with {cursor_type} cursor..."
+                        f"Executing lineage query {query_index}/{len(queries)} for time range {self.config.start_time} to {self.config.end_time} with {cursor_type} cursor..."
                     )
 
                     # Use helper method to try server-side cursor with fallback
@@ -1583,80 +1613,71 @@ ORDER by DataBaseName, TableName;
         else:
             return connection.execute(text(query))
 
+    def _generate_aggregator_workunits(self) -> Iterable[MetadataWorkUnit]:
+        """Override to prevent parent class from generating aggregator work units during schema extraction.
+
+        We handle aggregator generation manually after populating it with audit log data.
+        """
+        # Do nothing - we'll call the parent implementation manually after populating the aggregator
+        return iter([])
+
     def get_workunits_internal(self) -> Iterable[MetadataWorkUnit]:
         logger.info("Starting Teradata metadata extraction")
 
-        # Add all schemas to the schema resolver
-        # Sql parser operates on lowercase urns so we need to lowercase the urns
+        # Step 1: Schema extraction first (parent class will skip aggregator generation due to our override)
         with self.report.new_stage("Schema metadata extraction"):
             yield from super().get_workunits_internal()
             logger.info("Completed schema metadata extraction")
 
-        with self.report.new_stage("Audit log extraction"):
-            yield from self._get_audit_log_mcps_with_aggregator()
+        # Step 2: Lineage extraction after schema extraction
+        # This allows lineage processing to have access to all discovered schema information
+        with self.report.new_stage("Audit log extraction and lineage processing"):
+            self._populate_aggregator_from_audit_logs()
+            # Call parent implementation directly to generate aggregator work units
+            yield from super()._generate_aggregator_workunits()
+            logger.info("Completed lineage processing")
 
-        # SqlParsingAggregator handles its own work unit generation internally
-        logger.info("Lineage processing completed by SqlParsingAggregator")
-
-    def _generate_aggregator_workunits(self) -> Iterable[MetadataWorkUnit]:
-        """Override base class to skip aggregator gen_metadata() call.
-
-        Teradata handles aggregator processing after adding audit log queries,
-        so we skip the base class call to prevent duplicate processing.
-        """
-        # Return empty iterator - Teradata will handle aggregator processing
-        # after adding audit log queries in _get_audit_log_mcps_with_aggregator()
-        return iter([])
-
-    def _get_audit_log_mcps_with_aggregator(self) -> Iterable[MetadataWorkUnit]:
+    def _populate_aggregator_from_audit_logs(self) -> None:
         """SqlParsingAggregator-based lineage extraction with enhanced capabilities."""
-        logger.info(
-            "Fetching queries from Teradata audit logs for SqlParsingAggregator"
-        )
-
-        if self.config.include_table_lineage or self.config.include_usage_statistics:
-            # Step 1: Stream query entries from database with memory-efficient processing
-            with self.report.new_stage("Fetching lineage entries from Audit Logs"):
-                queries_processed = 0
-                entries_processed = False
-
-                # Use streaming query reconstruction for memory efficiency
-                for observed_query in self._reconstruct_queries_streaming(
-                    self._fetch_lineage_entries_chunked()
-                ):
-                    entries_processed = True
-                    self.aggregator.add(observed_query)
-
-                    queries_processed += 1
-                    if queries_processed % 10000 == 0:
-                        logger.info(
-                            f"Processed {queries_processed} queries to aggregator"
-                        )
-
-                if not entries_processed:
-                    logger.info("No lineage entries found")
-                    return
-
-                logger.info(
-                    f"Completed adding {queries_processed} queries to SqlParsingAggregator"
-                )
-
-        # Step 2: Generate work units from aggregator
-        with self.report.new_stage("SqlParsingAggregator metadata generation"):
-            logger.info("Generating metadata work units from SqlParsingAggregator")
-            work_unit_count = 0
-            for mcp in self.aggregator.gen_metadata():
-                work_unit_count += 1
-                if work_unit_count % 10000 == 0:
-                    logger.info(
-                        f"Generated {work_unit_count} work units from aggregator"
-                    )
-                yield mcp.as_workunit()
+        with self.report.new_stage("Lineage extraction from Teradata audit logs"):
+            # Record the lineage query time range in the report
+            self.report.lineage_start_time = self.config.start_time
+            self.report.lineage_end_time = self.config.end_time
 
             logger.info(
-                f"Completed SqlParsingAggregator processing: {work_unit_count} work units generated"
+                f"Starting lineage extraction from Teradata audit logs (time range: {self.config.start_time} to {self.config.end_time})"
             )
 
+            if (
+                self.config.include_table_lineage
+                or self.config.include_usage_statistics
+            ):
+                # Step 1: Stream query entries from database with memory-efficient processing
+                with self.report.new_stage("Fetching lineage entries from Audit Logs"):
+                    queries_processed = 0
+
+                    # Use streaming query reconstruction for memory efficiency
+                    for observed_query in self._reconstruct_queries_streaming(
+                        self._fetch_lineage_entries_chunked()
+                    ):
+                        self.aggregator.add(observed_query)
+
+                        queries_processed += 1
+                        if queries_processed % 10000 == 0:
+                            logger.info(
+                                f"Processed {queries_processed} queries to aggregator"
+                            )
+
+                    if queries_processed == 0:
+                        logger.info("No lineage entries found")
+                        return
+
+                    logger.info(
+                        f"Completed adding {queries_processed} queries to SqlParsingAggregator"
+                    )
+
+            logger.info("Completed lineage extraction from Teradata audit logs")
+
     def close(self) -> None:
         """Clean up resources when source is closed."""
         logger.info("Closing SqlParsingAggregator")
